@@ -1,8 +1,8 @@
-__version__ = "0.0.3"
+__version__ = "0.0.7"
 
 from .vem_pixel_classifier import VEMSEGClassifier
 from .predict_pixel_classifier import VEMSEGClassifierPredict
-from . phh_predict import PHHPredictWidget
+# from .phh_predict import PHHPredictWidget
 
 # __all__ = (
 #     "VEMSEGClassifier",
